"use strict";
// Copyright (c) Microsoft Corporation.
// Licensed under the MIT license.
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Returns width and height of the active page as an object
 * @param report PowerBI Report
 */
function getActivePageSize(report) {
    return __awaiter(this, void 0, void 0, function* () {
        const pages = yield report.getPages();
        // Get the active page
        const activePage = pages.find((page) => {
            return page.isActive;
        });
        if (!activePage) {
            throw 'No active report page';
        }
        return activePage.defaultSize;
    });
}
exports.getActivePageSize = getActivePageSize;
function getRequestedPage(report, pageName) {
    return __awaiter(this, void 0, void 0, function* () {
        const pages = yield report.getPages();
        const requestedPage = pages.filter((page) => {
            return page.name === pageName;
        })[0];
        if (!requestedPage) {
            throw 'Page not found';
        }
        return requestedPage;
    });
}
exports.getRequestedPage = getRequestedPage;
/**
 * Returns width and height of the active page as an object
 * @param tokenExpiration Access token expiration timestamp
 * @param minutesToRefresh Minutes before expiration
 * @param reportView ReportView
 */
function setTokenExpirationListener(tokenExpiration, minutesToRefresh, reportView) {
    return __awaiter(this, void 0, void 0, function* () {
        // Get current time
        const currentTime = Date.now();
        const expiration = tokenExpiration * 1000;
        const safetyInterval = minutesToRefresh * 60 * 1000;
        // Time until token refresh in milliseconds
        const timeout = expiration - currentTime - safetyInterval;
        // If timeout reaches safetyInterval, invoke the setTokenExpiredFlag method
        if (timeout <= 0) {
            reportView.setTokenExpiredFlag();
        }
        else {
            // Set timeout so minutesToRefresh minutes before token expires, setTokenExpiredFlag will be invoked
            console.log('Report Access Token will be updated in ' + timeout + ' milliseconds.');
            setTimeout(() => {
                reportView.setTokenExpiredFlag();
            }, timeout);
        }
    });
}
exports.setTokenExpirationListener = setTokenExpirationListener;
//# sourceMappingURL=utils.js.map